@@ -8,6 +8,7 @@ tframe.zoo <- function (x) {
 
 tfUnSet.zoo <- function(x)      {zoo:::coredata(x)}
 tfSet.zootframe <- function(value, x) { 
+  if(Tobs(value) != Tobs(x)) stop("number of Tobs of observations must correspond to number of Tobs indicated by tframe.")
   class(value) <- class(value)[class(value) != "zootframe"]
   zoo:::zoo(x, value) }
 
@@ -17,12 +18,11 @@ tfSet.zootframe <- function(value, x) {
    x
   }
 
-tfperiods.zoo <- function(x)  NROW(x)
+Tobs.zoo <- function(x)  NROW(x)
 
 tfstart.zootframe <- function(x) x[1]
 tfend.zootframe   <- function(x) x[length(x)]
-tfperiods.zootframe   <- function(x) length(x)
-periods.zootframe     <- function(x) length(x)
+Tobs.zootframe     <- function(x) length(x)
 
 tfL.zoo <- function (x, p = 1) lag(x, k = -p)
 
